# Ojet package
 
### Introduction

Oracle JET is a great HTML application builder. The only flaw of this generator is the need to know both HTML and JAVASCRIPT!

This "ojet" package is a Python 3 wrapper around Oracle JET. Its aim is to hide as much as possible the complexity of the HTML and JAVASCRIPT code.

Furthurmore "ojet" can be included in a jupyter notebook in order to add sophisticated HTML views or to help to test an "ojet" application.

### License

"ojet" itself has a GNU general license, but the result of "ojet" must conform to the rules edicted by Oracle about the "Oracle JET" license.

### Installation

Install, upgrade and uninstall ojet with the following commands:

::

    $ pip3 install ojet
    $ pip3 install --upgrade ojet
    $ pip3 uninstall ojet

### Dependencies

IPython is needed when "ojet" is used in a jupyter notebook

### Documentation

There is no specific documentation about ojet except the jupyter notebook attached.